from django.test import SimpleTestCase
from mock import patch
from suds.sax.text import Text
from contrib.umws.test_utils import ClientMock
from .sms_service import sms_service


class ShortMessageServiceClientMock(ClientMock):
    """
    Mock object that implements Short Message Service
    """

    def SendMessage(self, number, message, anonymous):  # noqa
        """ Send Message method
        """
        return Text(999999)

    def GetMessageStatus(self, msgid):  # noqa
        """ Get Message Status
        """
        return Text("SMS does not exist in context.")


class SMSServiceTestCase(SimpleTestCase):
    """ """

    @patch('contrib.umws.sms.sms_service.get_client')
    def test_send_message(self, get_client):
        """ """
        get_client.return_value = ShortMessageServiceClientMock("url_wsdl")
        msgid = sms_service.send_message('910000000', 'Msg')
        self.assertEquals(msgid, '999999')

    @patch('contrib.umws.sms.sms_service.get_client')
    def test_get_message_status(self, get_client):
        """ """
        get_client.return_value = ShortMessageServiceClientMock("url_wsdl")
        status = sms_service.get_message_status("999999")
        self.assertEqual(status, "SMS does not exist in context.")
