import os
import mimetypes

from django.core.urlresolvers import reverse_lazy

from evote.settings import *  # NOQA


# HACK: support serving svg images

mimetypes.add_type("image/svg+xml", ".svg", True)
mimetypes.add_type("image/svg+xml", ".svgz", True)


# Django settings

SITE_ID = 1

DEBUG = True
TEMPLATE_DEBUG = True
THUMBNAIL_DEBUG = True

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': os.environ.get('MYSQL_DATABASE'),
        'USER': os.environ.get('MYSQL_USER'),
        'PASSWORD': os.environ.get('MYSQL_PASSWORD'),
        'HOST': 'db',
        'PORT': '3306'
    }
}

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": os.environ.get('REDIS_PORT'),
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}


# Auth settings

LOGIN_URL = reverse_lazy("voters:login")
LOGOUT_URL = reverse_lazy("voters:logout")

AUTHENTICATION_BACKENDS += [  # NOQA
    'django.contrib.auth.backends.ModelBackend',  # this is default
]


# Celery settings

CELERY_BROKER_URL = 'amqp://{}:{}@rabbitmq//'.format(
    os.environ.get('RABBITMQ_DEFAULT_USER'),
    os.environ.get('RABBITMQ_DEFAULT_PASS'))
CELERY_EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'


# Sorl thumbnail settings

THUMBNAIL_REDIS_URL = os.environ.get('REDIS_PORT')
THUMBNAIL_KVSTORE = "sorl.thumbnail.kvstores.redis_kvstore.KVStore"
THUMBNAIL_DUMMY = True
THUMBNAIL_DEBUG = True


# debug toolbar settings

DEBUG_TOOLBAR_PATCH_SETTINGS = False
INSTALLED_APPS += (  # NOQA
    'debug_toolbar',
)
MIDDLEWARE += [  # NOQA
    'debug_toolbar.middleware.DebugToolbarMiddleware',
]
DEBUG_TOOLBAR_CONFIG = {
    "SHOW_TOOLBAR_CALLBACK": lambda x: True,
}


# LOGGING

EVOTELOG_DIR = os.path.join(PROJECT_DIR, '../data/')  # NOQA
EVOTELOG_MAIL_LIST = ADMINS  # NOQA

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'verbose': {
            'format': '[%(asctime)s] - (%(levelname)s) %(pathname)s\
                    at line: %(lineno)d - %(message)s'
        },
        'simple': {
            'format': '[%(asctime)s] - %(levelname)s - %(message)s'
        },
    },
    'handlers': {
        'console': {
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
            'formatter': 'simple'
        },
    },
    'loggers': {
        'evote.logger': {
            'handlers': ['console'],
            'level': 'WARNING',
            'propagate': False,
        }
    },
}
