import os

from evote.settings import *  # noqa
from django.core.urlresolvers import reverse_lazy


DEBUG = False
TEMPLATE_DEBUG = True
COMPRESS_OFFLINE = True

SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')

ALLOWED_HOSTS = [os.environ.get('SN_EVOTE')]

# Django Site identification
SITE_ID = 10

SECRET_KEY = os.environ.get('SECRET_KEY')

MIDDLEWARE += (  # noqa
    'django.middleware.gzip.GZipMiddleware',
)

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': os.environ.get('MYSQL_DATABASE'),
        'USER': os.environ.get('MYSQL_USER'),
        'PASSWORD': os.environ.get('MYSQL_PASSWORD'),
        'HOST': os.environ.get('MYSQL_HOST'),
        'PORT': '',
        'OPTIONS': {
            'init_command': 'SET storage_engine=INNODB'
        },
    }
}

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": os.environ.get('REDIS_URL'),
        "KEY_PREFIX": "evote",
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}

LOGIN_URL = reverse_lazy("adfsauth:ws-fed-signin")
LOGOUT_URL = reverse_lazy("adfsauth:ws-fed-signout")

AUTHENTICATION_BACKENDS = (
    'django.contrib.auth.backends.ModelBackend',  # this is default
    'guardian.backends.ObjectPermissionBackend',
    'contrib.adfsauth.backends.WSFedBackend'
)

# Define the Queue Settings

CELERY_BROKER_URL = os.environ.get('BROKER_URL')


# sorl thumbnail settings

THUMBNAIL_REDIS_URL = os.environ.get('REDIS_URL')
THUMBNAIL_KVSTORE = "sorl.thumbnail.kvstores.redis_kvstore.KVStore"


# Logging
# Inherited from base settings
EVOTELOG_MAIL_LIST = [('Dev', 'dev-errors@eurotux.com')]

# Contact Info
EVOTE_CONTACT_NAME = 'Evotum Team'
EVOTE_CONTACT_MAIL = [(EVOTE_CONTACT_NAME, 'dev@eurotux.com')]


# WS UM Members
MEMBERS_SERVICE_CONFIG = {
    'debug': False,
    'url': 'https://ws.uminho.pt/ValidationServiceBasic/ValidationService.svc?wsdl',  # noqa
    'login': os.environ.get('WS_MEMBERS_LOGIN'),
    'password': os.environ.get('WS_MEMBERS_PASSWORD')
}

# WS UM SMS Notifications
SMS_SERVICE_CONFIG = {
    'debug': False,
    'url': 'https://ws.uminho.pt/ShortMessageServiceBasic/SimpleMessageService.svc?wsdl',  # noqa
    'login': os.environ.get('WS_SMS_LOGIN'),
    'password': os.environ.get('WS_SMS_PASSWORD')
}

# ADFS AUTH (WS-Fed Sign-In Protocol)
ADFS_WSFED = True
ADFS_WSFED_CONFIG = {
    'url': 'https://login.uminho.pt/adfs/ls/',
    'wtrealm': 'urn:uminho:evotum',
    'cert': os.path.join(PROJECT_DIR, '..', 'data', 'certs', 'um_adfs_autenticacao.pem'),  # noqa
    'claim_mapping': {'nome': 'name',
                      'upn': 'email',
                      'fotografia': 'photo',
                      'telemovel': 'primary_phone',
                      'nic': 'nic'},
    "template_fail": 'voters/signin_fail.html',
    "post_response": "wresult",
    "url_after_login": '',
}
