import os

from evote.settings import *  # noqa


# Django settings

SITE_ID = 1
DEBUG = False
TEMPLATE_DEBUG = False

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": ":memory:"
    },
}

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'evotevotings.voters.middleware.VotersMiddleware'
]

PASSWORD_HASHERS = (
    'django.contrib.auth.hashers.MD5PasswordHasher',
)

TEMPLATE_LOADERS = (
    ('django.template.loaders.cached.Loader', (
        'django.template.loaders.filesystem.Loader',
        'django.template.loaders.app_directories.Loader',
    )),
)

AUTHENTICATION_BACKENDS += [  # NOQA
    'django.contrib.auth.backends.ModelBackend',  # this is default
]


# force templatetags raise exception, even with degug false
class InvalidString(str):
    def __mod__(self, other):
        from django.template.base import TemplateSyntaxError
        raise TemplateSyntaxError(
            "Undefined variable or unknown value for: %s" % other)


TEMPLATES[0]['OPTIONS'].update({  # NOQA
    'string_if_invalid': InvalidString("%s")
})


# celery

CELERY_TASK_ALWAYS_EAGER = True
CELERY_TASK_EAGER_PROPAGATES = True
CELERY_BROKER_URL = "memory:///"
CELERY_EMAIL_BACKEND = 'django.core.mail.backends.dummy.EmailBackend'


# Celery email backend

DEFAULT_FROM_EMAIL = 'default@eurotux.com'
EVOTE_MAILING_REPLYTO_DEFAULT = 'default@eurotux.com'
EVOTE_MAILING_SUBJECT_DEFAULT = 'Unit test default'
EVOTE_MAILING_NOREPLY_DEFAULT = 'noreply@eurotux.com'


# sorl-thumbnails settings

THUMBNAIL_FORMAT = "PNG"


# Recaptcha testing

os.environ['RECAPTCHA_TESTING'] = 'True'


# SAML Configurations

SAML = {
    'session_dict': 'authgov',
    'session_consume': 'authgov_valid',
    'sp_cert_path': os.path.join(
        PROJECT_DIR, 'contrib/ama/tests/test.crt'), # NOQA
    'sp_pkey_path': os.path.join(
        PROJECT_DIR, 'contrib/ama/tests/test.private.key'), # NOQA
    'sp_pkey_passphrase': SECRET_KEY, # NOQA
    'idp_cert_path': os.path.join(
        PROJECT_DIR, 'contrib/ama/tests/test.crt'), # NOQA
    'idp_addr': 'https://preprod.autenticacao.gov.pt/fa/default.aspx',
    'provider_name': 'Universidade do Minho',
    'issuer': 'evotum.uminho.pt',
    'request_attributes': {
        'NIC': 'http://interop.gov.pt/MDC/Cidadao/NIC'
    }
}


# javascript_settings

JAVASCRIPT_SETTINGS_SCAN_MODULES = {}


# WS UM Members

MEMBERS_SERVICE_CONFIG = {
    'debug': False
}


# WS UM SMS Notifications

SMS_SERVICE_CONFIG = {
    'debug': False
}


# Evote services settings

EVOTE_SERVICES_ENDPOINTS = {
    'anonymizer': None,
    'counter': None
}


# LOGGING

LOGGING = {}
